---
title: "Hello, World"
date: 2013-04-20 15:10
categories: crotal
slug: hello-world
---

Welcome to Crotal, This is the first post, modify or remove it, and start your own blog!

Write you post like this:

```
---
title: "Hello, World"
date: 2013-04-20 15:10
categories: crotal
slug: hello-world
---

Welcome to Crotal, This is the first post, modify or remove it, and start your own blog!```
```
